{ pkgs, config, ... }:

let
  home = config.home-manager.users.jopejoe1;
  user = config.users.users.jopejoe1;
in
{
  users.users = {
    jopejoe1 = {
      isNormalUser = true;
      shell = pkgs.nushell;
      description = "Johannes Jöns";
      hashedPassword = "$2b$05$Uk84TY/RHlH8DIigUlFYjeorjTlCMEY9wN2pAcw5BLaPoc7dKiSsC";
      extraGroups = [ "wheel" ];
      uid = 1000;
      packages = with pkgs; [ ];
      openssh.authorizedKeys.keys = [
        "ssh-ed25519 AAAAC3NzaC1lZDI1NTE5AAAAIFZDUoC+1lNR2JTY1Q+vhXpuLmKMdVl2OMFLVbQ3cGkw jopejoe1@desktop"
      ];
    };
  };
  home-manager.users.jopejoe1 = {
    home = {
      username = user.name;
      homeDirectory = user.home;
      stateVersion = config.system.stateVersion;
    };

    programs = {
      nushell = {
        enable = true;
      };

      carapace.enable = true;
      carapace.enableNushellIntegration = true;

      starship = {
        enable = true;
        settings = {
          add_newline = true;
          character = {
            success_symbol = "[➜](bold green)";
            error_symbol = "[➜](bold red)";
          };
        };
      };

      direnv = {
        enable = true;
        nix-direnv.enable = true;
      };

      neovim = {
        enable = true;
        defaultEditor = true;
      };

      git = {
        enable = true;
        package = pkgs.git;
        userEmail = "johannes@joens.email";
        userName = "jopejoe1";
        extraConfig = {
          core = {
            whitespace = [
              "blank-at-eol"
              "blank-at-eof"
              "space-before-tab"
            ];
          };
        };
      };
    };

    xdg = {
      enable = true;
      mime.enable = true;
      cacheHome = "${home.home.homeDirectory}/.cache";
      configHome = "${home.home.homeDirectory}/.config";
      dataHome = "${home.home.homeDirectory}/.local/share";
      stateHome = "${home.home.homeDirectory}/.local/state";
      userDirs = {
        enable = true;
        createDirectories = true;
        desktop = "${home.home.homeDirectory}/Desktop";
        documents = "${home.home.homeDirectory}/Documents";
        download = "${home.home.homeDirectory}/Downloads";
        music = "${home.home.homeDirectory}/Music";
        pictures = "${home.home.homeDirectory}/Pictures";
        publicShare = "${home.home.homeDirectory}/Public";
        templates = "${home.home.homeDirectory}/Templates";
        videos = "${home.home.homeDirectory}/Videos";
      };
    };
  };
}
